==> libcommons-compress-java_1.17.orig.tar.xz: commons-compress-1.17-src/src/test/java/org/apache/commons/compress/utils/SkipShieldingInputStreamTest.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */
package org.apache.commons.compress.utils;

import java.io.IOException;
import java.io.InputStream;
import org.junit.Assert;
import org.junit.Test;

public class SkipShieldingInputStreamTest {

    @Test
    public void skipDelegatesToRead() throws IOException {
        try (InputStream i = new SkipShieldingInputStream(new InputStream() {
                @Override
                public long skip(long n) {
                    Assert.fail("skip invoked");
                    return -1;
                }
                @Override
                public int read() {
                    return -1;
                }
                @Override
                public int read(byte[] b, int off, int len) {
                    return len;
                }
            })) {
            Assert.assertEquals(100, i.skip(100));
        }
    }

    @Test
    public void skipHasAnUpperBoundOnRead() throws IOException {
        try (InputStream i = new SkipShieldingInputStream(new InputStream() {
                @Override
                public long skip(long n) {
                    Assert.fail("skip invoked");
                    return -1;
                }
                @Override
                public int read() {
                    return -1;
                }
                @Override
                public int read(byte[] b, int off, int len) {
                    return len;
                }
            })) {
            Assert.assertTrue(Integer.MAX_VALUE > i.skip(Long.MAX_VALUE));
        }
    }

    @Test
    public void skipSwallowsNegativeArguments() throws IOException {
        try (InputStream i = new SkipShieldingInputStream(new InputStream() {
                @Override
                public long skip(long n) {
                    Assert.fail("skip invoked");
                    return -1;
                }
                @Override
                public int read() {
                    return -1;
                }
                @Override
                public int read(byte[] b, int off, int len) {
                    Assert.fail("read invoked");
                    return len;
                }
            })) {
            Assert.assertEquals(0, i.skip(Long.MIN_VALUE));
        }
    }

}

==> libcommons-compress-java_1.23.0.orig.tar.xz: commons-compress-1.23.0-src/src/test/java/org/apache/commons/compress/utils/SkipShieldingInputStreamTest.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */
package org.apache.commons.compress.utils;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertTrue;
import static org.junit.jupiter.api.Assertions.fail;

import java.io.IOException;
import java.io.InputStream;

import org.junit.jupiter.api.Test;

public class SkipShieldingInputStreamTest {

    @Test
    public void skipDelegatesToRead() throws IOException {
        try (InputStream i = new SkipShieldingInputStream(new InputStream() {
                @Override
                public int read() {
                    return -1;
                }
                @Override
                public int read(byte[] b, int off, int len) {
                    return len;
                }
                @Override
                public long skip(long n) {
                    fail("skip invoked");
                    return -1;
                }
            })) {
            assertEquals(100, i.skip(100));
        }
    }

    @Test
    public void skipHasAnUpperBoundOnRead() throws IOException {
        try (InputStream i = new SkipShieldingInputStream(new InputStream() {
                @Override
                public int read() {
                    return -1;
                }
                @Override
                public int read(byte[] b, int off, int len) {
                    return len;
                }
                @Override
                public long skip(long n) {
                    fail("skip invoked");
                    return -1;
                }
            })) {
            assertTrue(Integer.MAX_VALUE > i.skip(Long.MAX_VALUE));
        }
    }

    @Test
    public void skipSwallowsNegativeArguments() throws IOException {
        try (InputStream i = new SkipShieldingInputStream(new InputStream() {
                @Override
                public int read() {
                    return -1;
                }
                @Override
                public int read(byte[] b, int off, int len) {
                    fail("read invoked");
                    return len;
                }
                @Override
                public long skip(long n) {
                    fail("skip invoked");
                    return -1;
                }
            })) {
            assertEquals(0, i.skip(Long.MIN_VALUE));
        }
    }

}
